@@ -73,6 +73,6 @@ class Listing(BaseModel):
     production_partners: List[ProductionPartner]
     skus: List[str]
     translations: Optional[List[Translation]]
-    inventory: Inventory
+    inventory: Optional[Inventory]
     
 Inventory.update_forward_refs()
\ No newline at end of file
