@@ -107,7 +107,8 @@ class ListingResource:
             data["sku_on_property"] = sku_on_property
             
         endpoint = f"listings/{listing_id}/inventory"
-
+        print(json.dumps(data))
+        print(endpoint)
         response = self.auth.request(endpoint, "PUT", data=json.dumps(data))
         return Inventory(**response)
 
